
#include <cstdio>
#include <cmath>
#include <vector>
#include <iostream>
using namespace std;

struct vec
{
    double x, y;
    
    vec (double x = 0.0, double y = 0.0)
    {
        this -> x = x;
        this -> y = y;
    }
    
    void show ()
    {
        printf ("(%lf, %lf)\n", x, y);
    }
    
    vec operator ~ ()
    {
        return vec (-y, x);
    }
    
    double len ()
    {
        return sqrt (x * x + y * y);
    }
    
    inline bool operator < (const vec &rhs) const
    {
        if (x != rhs.x)
            return x < rhs.x;
        return y < rhs.y;
    }
};

inline vec operator + (vec a, vec b) {return vec (a.x + b.x, a.y + b.y);}
inline vec operator - (vec a, vec b) {return vec (a.x - b.x, a.y - b.y);}
inline vec operator / (vec a, double d) {return vec (a.x / d, a.y / d);}
inline vec operator * (vec a, double d) {return vec (a.x * d, a.y * d);}

inline double cross (vec &a, vec &b, vec &c)
{
    return a.x * (b.y - c.y) + b.x * (c.y - a.y) + c.x * (a.y - b.y);
}

inline double _dist (vec &a, vec &b)
{
    return sqrt ((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}

struct circle
{
    vec c;
    double r;
    
    circle () {}
    circle (vec c, double r)
    {
        this -> c = c;
        this -> r = r;
    }
    
    inline double dist (vec x)
    {
        return max (0.0, _dist (c, x) - r);
    }
};

int N;
double L;

vector <circle> circles;
vector <vector <vec> > rects;

vector <vec> convex_hull (vector <vec> poly)
{
    sort (poly.begin (), poly.end ());
    do
    {
        bool ok = true;
        for (int j = 0; j < 4; ++j)
            if (cross (poly [j], poly [(j + 1) % 4], poly [(j + 2) % 4]) < 0.0)
                ok = false;
        if (ok)
            break;
    } while (next_permutation (poly.begin (), poly.end ()));
    return poly;
}
void read ()
{
    scanf ("%lf", &L);
    scanf ("%d", &N);
    for (int i = 0; i < N; ++i)
    {
        double x1, y1, x2, y2;
//        scanf ("%lf %lf %lf %lf", &x1, &y1, &x2, &y2);
        cin >> x1 >> y1 >> x2 >> y2;
        circles.push_back (circle (vec (x1, y1), 50.0));
        circles.push_back (circle (vec (x2, y2), 50.0));
        
        vec a (x1, y1), b (x2, y2);
        vec a_b = b - a, b_a = a - b;
        if (a_b.len () > 0.0)
            a_b = a_b / a_b.len ();
        if (b_a.len () > 0.0)
            b_a = b_a / b_a.len ();
        a_b = a_b * 50.0;
        b_a = b_a * 50.0;
        
        vec m = ~a_b + a;
        vec n = ~~~a_b + a;
        vec p = ~b_a + b;
        vec q = ~~~b_a + b;
        vector <vec> poly;
        poly.push_back (m);
        poly.push_back (n);
        poly.push_back (p);
        poly.push_back (q);
        rects.push_back (convex_hull (poly));
        
//        for (int j = 0; j < rects [0].size (); ++j)
//           rects [0][j].show ();
        
    }
}

inline vec xpoint (vec &a, vec &b, vec &c, vec &d)
{
    double s1 = cross (a, d, c);
    double s2 = cross (c, d, b);
    if (fabs (s1 + s2) < 1e-12)
        return vec (1e10, 1e10);
    return a + (b - a) * (s1 / (s1 + s2));
}

inline bool equal (double x, double y)
{
    return fabs (x - y) < 1e-9;
}

inline double dist_to_poly (vector <vec> &poly, vec p)
{
    double res = 1e100;
    for (int i = 0; i < (int) poly.size (); ++i)
        res = min (res, _dist (poly [i], p));
    for (int i = 0; i < (int) poly.size (); ++i)
    {
        vec z = ~(poly [i] - poly [(i + 1) % (int) poly.size ()]) + p;
        vec pz = p + z;
        vec x = xpoint (p, pz, poly [i], poly [(i + 1) % (int) poly.size ()]);
        if (equal (_dist (poly [i], poly [(i + 1) % (int) poly.size ()]), 
            _dist (poly [i], x) + _dist (x, poly [(i + 1) % (int) poly.size ()])))
            res = min (res, _dist (x, p));
    }
    bool pos = false, neg = false;
    for (int i = 0; i < (int) poly.size (); ++i)
    {
        double d = cross (poly [i], poly [(i + 1) % (int) poly.size ()], p);
        if (d > 0.0) pos = true;
        if (d < 0.0) neg = true;
    }
    if (!neg)
        res = 0.0;
    return res;
}

void shit ()
{
    vector <vec> poly (4);
    poly [0] = vec (0, 0);
    poly [1] = vec (1, 1);
    poly [2] = vec (0, 2);
    poly [3] = vec (-1, 1);
    
    cout << dist_to_poly (poly, vec (2, -1)) << endl;
}

double eval (vec v)
{
    double res = 1e100;
    for (int i = 0; i < (int) circles.size (); ++i)
        res = min (res, circles [i].dist (v));
    for (int i = 0; i < (int) rects.size (); ++i)
        res = min (res, dist_to_poly (rects [i], v));
//    cout << v.x << " " << v.y << " " << res << endl;
    return res;
}

pair <double, double> ternary_y (double x)
{
    double left = 0.0;
    double right = L;
    while (right - left > 1e-9)
    {
        double a = (left + left + right) / 3.0;
        double b = (left + right + right) / 3.0;
        if (eval (vec (x, a)) > eval (vec (x, b)))
            right = b;
        else
            left = a;
    }
    return make_pair (eval ((left + right) / 2.0), (left + right) / 2.0);
}

void solve ()
{
    double left = 0.0;
    double right = L;
    while (right - left > 1e-9)
    {
        double a = (left + left + right) / 3.0;
        double b = (left + right + right) / 3.0;
        if (ternary_y (a) > ternary_y (b))
            right = b;
        else
            left = a;
    }
    double x = (left + right) / 2.0;
    pair <double, double> y = ternary_y (x);
    printf ("%.20lf %.20lf\n", x, y.second);
}

int main ()
{
    read ();
    solve ();
    return 0;
}
