#include <cstdio>
#include <cmath>
#include <cstdlib>
#include <ctime>

#define ldouble double

int L, N;

struct pointd {
	ldouble x, y;
	
	pointd() { }
	pointd(ldouble _x, ldouble _y) : x(_x), y(_y) { }
	pointd(pointd& a, pointd& b) {
		x = b.x - a.x;
		y = b.y - a.y;
	}
	
	pointd operator+ (pointd a) {
		return pointd(a.x+x, a.y+y);
	}
	
	double length() {
		return x*x + y*y;
	}
	
	void resize(double new_size) {
		double coef = new_size / sqrt(length());
		x *= coef;
		y *= coef;
	}
};

pointd intersect(pointd p1, pointd p2, pointd p3, pointd p4) {
	double den = (p4.y-p3.y)*(p2.x-p1.x) - (p4.x-p3.x)*(p2.y-p1.y);
	
	if(den == 0) return pointd(-1, -1);
	
	double ua = ((p4.x-p3.x)*(p1.y-p3.y)-(p4.y-p3.y)*(p1.x-p3.x)) / den;
	//double ua = ((p2.x-p1.x)*(p1.y-p3.y)-(p2.y-p1.y)*(p1.x-p3.x)) / den;
	
	return pointd(p1.x + ua*(p2.x-p1.x), p1.y + ua*(p2.y-p1.y));
}

struct sick {
	pointd a, b;
} z[128];

void input() {
	scanf("%d%d", &L, &N);
	for(int i = 0; i < N; ++i) scanf("%lf%lf%lf%lf", &z[i].a.x, &z[i].a.y, &z[i].b.x, &z[i].b.y);
}

bool valid(pointd p) {
	for(int i = 0; i < N; ++i) {
		pointd my_vec = pointd(z[i].a, z[i].b);
		my_vec.resize(3000);
		my_vec = pointd(-my_vec.y, my_vec.x);
		my_vec.x -= my_vec.x / 2;
		my_vec.y -= my_vec.y / 2;
		
		pointd inter = intersect(z[i].a, z[i].b, p, pointd(p.x + my_vec.x, p.y + my_vec.y));
		
		if(pointd(p, inter).length() <= 250) return false;
	}
	return true;
}

double rand(double max) {
	return rand() / (double)RAND_MAX * max;
}

int main() {
	long start = clock();
	input();
	srand(time(0));
	pointd rnd;
	int i = 0;
	while(1) {
		rnd.x = rand(L);
		rnd.y = rand(L);
		if(valid(rnd)) {
			printf("%lf %lf\n", rnd.x, rnd.y);
			return 0;
		}
		++i;
		if(i % 100 == 0) {
			if(clock()-start >= CLK_TCK*0.9) break;
		}
	}
	printf("NO WAY\n");
	return 0;
}
